@@ -752,7 +752,7 @@ void do_color_print(proginfo *cur, char *use_string, int prt_start, int prt_end,
 
 char *escape(const char *what, const proginfo *const cur)
 {
-	char *temp = strdup(what);
+	char *temp = strdup(what ? what : "");
 
 	for(;;) {
 		char *new_str = NULL;
@@ -1486,14 +1486,8 @@ void update_statusline(NEWWIN *status, int win_nr, proginfo *cur)
 				else
 				{
 					cur_len = 13;
-					/* is this trick still neccessary as I moved from off_t to off64_t? */
-#if 0
-					/* this trick is because on MacOS X 'off_t' is specified as a 64 bit integer */
-#endif
-					if (sizeof(off64_t) == 8)
-						mvwprintw(status -> win, 0, win_width - (strlen(timestamp) + cur_len), "%10lld - %s", fsize, timestamp);
-					else
-						mvwprintw(status -> win, 0, win_width - (strlen(timestamp) + cur_len), "%10ld - %s", fsize, timestamp);
+					/* Accomodate for both 32-bit and 64-bit off_t. */
+					mvwprintw(status -> win, 0, win_width - (strlen(timestamp) + cur_len), "%10lld - %s", (long long)fsize, timestamp);
 				}
 
 				total_info_len = statusline_len + cur_len;
@@ -1770,7 +1764,7 @@ void create_windows(void)
 		menu_win = mynewwin(max_y, max_x, 0, 0);
 		werase(menu_win -> win);
 
-		wprintw(menu_win -> win, version_str);
+		wprintw(menu_win -> win, "%s", version_str);
 		wprintw(menu_win -> win, "\n\n");
 
 		wprintw(menu_win -> win, "%s\n", F1);
@@ -3044,9 +3038,9 @@ void create_new_win(proginfo **cur, int *nr)
 
 int check_paths(void)
 {
-	int new_wins = 0;
-	int loop = 0;
-	dtime_t now = get_ts();
+	int     new_wins = 0;
+	int     loop     = 0;
+	dtime_t now      = get_ts();
 
 	for(loop=0; loop<n_cdg; loop++)
 	{
@@ -3077,8 +3071,8 @@ int check_paths(void)
 						((cdg[loop].new_only && last_mod >= mt_started) || !cdg[loop].new_only)
 				   )
 				{
-					proginfo *cur = NULL;
-					int win_nr = -1;
+					proginfo *cur    = NULL;
+					int       win_nr = -1;
 
 					/* create new structure containing all info and such */
 					if (!cdg[loop].in_one_window)
@@ -3103,9 +3097,10 @@ int check_paths(void)
 					}
 
 					/* fill in */
-					cur -> wt = WT_FILE;
-					cur -> filename = mystrdup(files.gl_pathv[fi]);
-					cur -> line_wrap = default_linewrap;
+					cur -> wt         = WT_FILE;
+					cur -> label      = mystrdup(cdg[loop].label ? cdg[loop].label : "");
+					cur -> filename   = mystrdup(files.gl_pathv[fi]);
+					cur -> line_wrap  = default_linewrap;
 					cur -> win_height = -1;
 					cur -> statistics.sccfirst = 1;
 					set_default_parameters_if_not_given_do(cur, win_nr);
